@@ -9,6 +9,8 @@ from InquirerPy.exceptions import InvalidArgument, RequiredKeyNotFound
 from InquirerPy.separator import Separator
 from InquirerPy.utils import InquirerPyStyle, SessionResult
 
+__all__ = ["ExpandPrompt"]
+
 
 class ExpandHelp(NamedTuple):
     """A struct class to identify if user selected the help choice."""
@@ -32,17 +34,23 @@ class InquirerPyExpandControl(InquirerPyUIControl):
         expand_pointer: str,
         marker: str,
         session_result: Optional[SessionResult],
+        multiselect: bool,
+        marker_pl: str = " ",
     ) -> None:
         """Construct content control object and initialise choices."""
         self._pointer = pointer
         self._separator = separator
         self._expanded = False
         self._key_maps = {}
-        self._expand_pointer = "%s " % expand_pointer
+        self._expand_pointer = expand_pointer
         self._marker = marker
+        self._marker_pl = marker_pl
         self._help_msg = help_msg
         super().__init__(
-            choices=choices, default=default, session_result=session_result
+            choices=choices,
+            default=default,
+            session_result=session_result,
+            multiselect=multiselect,
         )
 
     def _format_choices(self) -> None:
@@ -111,12 +119,12 @@ class InquirerPyExpandControl(InquirerPyUIControl):
         display_choices.append(
             (
                 "class:marker",
-                self._marker if choice["enabled"] else " ",
+                self._marker if choice["enabled"] else self._marker_pl,
             )
         )
         if not isinstance(choice["value"], Separator):
             display_choices.append(
-                ("class:pointer", "%s%s " % (choice["key"], self._separator))
+                ("class:pointer", "%s%s" % (choice["key"], self._separator))
             )
         display_choices.append(("[SetCursorPosition]", ""))
         display_choices.append(("class:pointer", choice["name"]))
@@ -128,11 +136,11 @@ class InquirerPyExpandControl(InquirerPyUIControl):
         display_choices.append(
             (
                 "class:marker",
-                self._marker if choice["enabled"] else " ",
+                self._marker if choice["enabled"] else self._marker_pl,
             )
         )
         if not isinstance(choice["value"], Separator):
-            display_choices.append(("", "%s%s " % (choice["key"], self._separator)))
+            display_choices.append(("", "%s%s" % (choice["key"], self._separator)))
             display_choices.append(("", choice["name"]))
         else:
             display_choices.append(("class:separator", choice["name"]))
@@ -145,48 +153,28 @@ class ExpandPrompt(BaseListPrompt):
     Prompt contains 2 state, expanded and not expanded. The visual effect are
     all controled via InquirerPyExpandControl under one window.
 
-    :param message: message to ask user
-    :type message: Union[str, Callable[[SessionResult], str]]
-    :param choices: list of choices to display
-    :type choices: Union[Callable[[SessionResult], List[Any]], List[Any]],
-    :param default: default value, can be a key of the choices or a value
-    :type default: Any
-    :param style: style dict to apply to the prompt
-    :type style: InquirerPyStyle
-    :param vi_mode: use vi kb for the prompt
-    :type vi_mode: bool
-    :param qmark: question qmark to display
-    :type qmark: str
-    :param pointer: pointer qmark to indicate current selected line
-    :type pointer: str
-    :param separator: separator qmark to display between the shortcut key and the content
-    :type separator: str
-    :param help_msg: help message to display to the user
-    :type help_msg: str
-    :param expand_pointer: visual pointer before expansion of the prompt
-    :type expand_pointer: str
-    :param instruction: override the default instruction e.g. (Yabh)
-    :type instruction: str
-    :param transformer: a callable to transform the result, this is visual effect only
-    :type transformer: Callable[[Any], Any]
-    :param filter: a callable to filter the result, updating the user input before returning the result
-    :type filter: Callable[[Any], Any]
-    :param height: preferred height of the choice window
-    :type height: Union[str, int]
-    :param max_height: max height choice window should reach
-    :type max_height: Union[str, int]
-    :param multiselect: enable multiselectiion
-    :type multiselect: bool
-    :param marker: marker symbol to indicate selected choice in multiselect mode
-    :type marker: str
-    :param validate: a callable or Validator instance to validate user selection
-    :type validate: Union[Callable[[Any], bool], Validator]
-    :param invalid_message: message to display when input is invalid
-    :type invalid_message: str
-    :param keybindings: custom keybindings to apply
-    :type keybindings: Dict[str, List[Dict[str, Any]]]
-    :param show_cursor: display cursor at the end of the prompt
-    :type show_cursor: bool
+    :param message: Message to ask user.
+    :param choices: List of choices to display.
+    :param default: Default value, can be a key of the choices or a value.
+    :param style: Style dict to apply to the prompt.
+    :param vi_mode: Use vi keybindings for the prompt.
+    :param qmark: The question qmark to display.
+    :param pointer: Pointer qmark to indicate current selected line.
+    :param separator: Separator qmark to display between the shortcut key and the content.
+    :param help_msg: Help message to display to the user.
+    :param expand_pointer: Visual pointer before expansion of the prompt.
+    :param instruction: Override the default instruction e.g. (Yabh).
+    :param transformer: A callable to transform the result, this is visual effect only.
+    :param filter: A callable to filter the result, updating the user input before returning the result.
+    :param height: Preferred height of the choice window.
+    :param max_height: Max height choice window should reach.
+    :param multiselect: Enable multiselectiion.
+    :param marker: Marker symbol to indicate selected choice in multiselect mode
+    :param marker_pl: Marker place holder for non selected choices.
+    :param validate: A callable or Validator instance to validate user selection.
+    :param invalid_message: Message to display when input is invalid.
+    :param keybindings: Custom keybindings to apply.
+    :param show_cursor: Display cursor at the end of the prompt.
     """
 
     def __init__(
@@ -198,9 +186,9 @@ class ExpandPrompt(BaseListPrompt):
         vi_mode: bool = False,
         qmark: str = "?",
         pointer: str = " ",
-        separator: str = ")",
+        separator: str = ") ",
         help_msg: str = "Help, list all choices",
-        expand_pointer: str = INQUIRERPY_POINTER_SEQUENCE,
+        expand_pointer: str = "%s " % INQUIRERPY_POINTER_SEQUENCE,
         instruction: str = "",
         transformer: Callable[[Any], Any] = None,
         filter: Callable[[Any], Any] = None,
@@ -208,6 +196,7 @@ class ExpandPrompt(BaseListPrompt):
         max_height: Union[int, str] = None,
         multiselect: bool = False,
         marker: str = INQUIRERPY_POINTER_SEQUENCE,
+        marker_pl: str = " ",
         validate: Union[Callable[[Any], bool], Validator] = None,
         invalid_message: str = "Invalid input",
         keybindings: Dict[str, List[Dict[str, Any]]] = None,
@@ -223,7 +212,9 @@ class ExpandPrompt(BaseListPrompt):
             help_msg=help_msg,
             expand_pointer=expand_pointer,
             marker=marker,
+            marker_pl=marker_pl,
             session_result=session_result,
+            multiselect=multiselect,
         )
         super().__init__(
             message=message,
