@@ -22,6 +22,8 @@ from InquirerPy.prompts.fuzzy.fzy import fuzzy_match_py_async
 from InquirerPy.separator import Separator
 from InquirerPy.utils import InquirerPyStyle, SessionResult, calculate_height
 
+__all__ = ["FuzzyPrompt"]
+
 
 class InquirerPyFuzzyControl(InquirerPyUIControl):
     """A UIControl element intended to be used by `prompt_toolkit` Window class.
@@ -34,6 +36,9 @@ class InquirerPyFuzzyControl(InquirerPyUIControl):
     :param marker: Marker symbol for the selected choice in the case of multiselect.
     :param current_text: Current buffer text.
     :param max_lines: Maximum height.
+    :param session_result: Current session result.
+    :param multiselect: Enable multiselect.
+    :param marker_pl: Marker place holder for non selected choices.
     """
 
     def __init__(
@@ -44,18 +49,25 @@ class InquirerPyFuzzyControl(InquirerPyUIControl):
         current_text: Callable[[], str],
         max_lines: int,
         session_result: Optional[SessionResult],
+        multiselect: bool,
+        marker_pl: str = " ",
     ) -> None:
         self._pointer = pointer
         self._marker = marker
+        self._marker_pl = marker_pl
         self._current_text = current_text
         self._max_lines = max_lines if max_lines > 0 else 1
-        super().__init__(choices=choices, default=None, session_result=session_result)
+        super().__init__(
+            choices=choices,
+            default=None,
+            session_result=session_result,
+            multiselect=multiselect,
+        )
 
     def _format_choices(self) -> None:
         for index, choice in enumerate(self.choices):
             if isinstance(choice["value"], Separator):
                 raise InvalidArgument("fuzzy type prompt does not accept Separator.")
-            choice["enabled"] = False
             choice["index"] = index
             choice["indices"] = []
         self._filtered_choices = self.choices
@@ -76,7 +88,9 @@ class InquirerPyFuzzyControl(InquirerPyUIControl):
         display_choices.append(
             (
                 "class:marker",
-                self._marker if self.choices[choice["index"]]["enabled"] else " ",
+                self._marker
+                if self.choices[choice["index"]]["enabled"]
+                else self._marker_pl,
             )
         )
         display_choices.append(("[SetCursorPosition]", ""))
@@ -106,7 +120,9 @@ class InquirerPyFuzzyControl(InquirerPyUIControl):
         display_choices.append(
             (
                 "class:marker",
-                self._marker if self.choices[choice["index"]]["enabled"] else " ",
+                self._marker
+                if self.choices[choice["index"]]["enabled"]
+                else self._marker_pl,
             )
         )
         if not choice["indices"]:
@@ -217,26 +233,27 @@ class FuzzyPrompt(BaseComplexPrompt):
     Override the default keybindings as j/k cannot be bind even if editing_mode is vim
     due to the input buffer.
 
-    :param message: message to display to the user
-    :param choices: list of choices available to select
-    :param default: default value to insert into buffer
-    :param pointer: pointer symbol
-    :param style: style dict to apply
-    :param vi_mode: use vi kb for the prompt
-    :param qmark: question mark symbol
-    :param transformer: transform the result to output, this is only visual effect
-    :param filter: a callable to filter the result, updating the user input before returning the result
-    :param instruction: instruction to display after the message
-    :param multiselect: enable multi selection of the choices
-    :param prompt: prompt symbol for buffer
-    :param marker: marker symbol for the selected choice in the case of multiselect
-    :param border: enable border around the fuzzy prompt
-    :param info: display info as virtual text after input
-    :param height: preferred height of the choice window
-    :param max_height: max height choice window should reach
-    :param validate: a callable or Validator instance to validate user selection
-    :param invalid_message: message to display when input is invalid
-    :param keybindings: custom keybindings to apply
+    :param message: Message to display to the user.
+    :param choices: List of choices available to select.
+    :param default: Default value to insert into buffer.
+    :param pointer: Pointer symbol.
+    :param style: Style dict to apply.
+    :param vi_mode: Use vi kb for the prompt.
+    :param qmark: Question mark symbol.
+    :param transformer: Transform the result to output, this is only visual effect.
+    :param filter: A callable to filter the result, updating the user input before returning the result.
+    :param instruction: Instruction to display after the message.
+    :param multiselect: Enable multi selection of the choices.
+    :param prompt: Prompt symbol for buffer.
+    :param marker: Marker symbol for the selected choice in the case of multiselect.
+    :param marker_pl: Marker place holder for non selected choices.
+    :param border: Enable border around the fuzzy prompt.
+    :param info: Display info as virtual text after input.
+    :param height: Preferred height of the choice window.
+    :param max_height: Max height choice window should reach.
+    :param validate: A callable or Validator instance to validate user selection.
+    :param invalid_message: Message to display when input is invalid.
+    :param keybindings: Custom keybindings to apply.
     """
 
     def __init__(
@@ -254,6 +271,7 @@ class FuzzyPrompt(BaseComplexPrompt):
         multiselect: bool = False,
         prompt: str = INQUIRERPY_POINTER_SEQUENCE,
         marker: str = INQUIRERPY_POINTER_SEQUENCE,
+        marker_pl: str = " ",
         border: bool = True,
         info: bool = True,
         height: Union[str, int] = None,
@@ -305,6 +323,8 @@ class FuzzyPrompt(BaseComplexPrompt):
             if not self._border
             else self._dimmension_max_height - 2,
             session_result=session_result,
+            multiselect=multiselect,
+            marker_pl=marker_pl,
         )
 
         self._buffer = Buffer(on_text_changed=self._on_text_changed)
